Returns a binary matrix of the same dimension. Missing value would be propogated into the binary matrix.
Arguments
CN
A matrix of gene wise copy number data for tumor samples. Rows are the genes; columns are the samples.
CNctr
A matrix of copy number data for normal samples. The program first guess if this is paired data by comparing if
tumor and normal sample has equal sample size. If TRUE, then normal samples will be subtracted element by element to
correct for germline CN change. Otherwise, no correction is performed. The program proceeds with only tumor data.
tau1
The lower bound for log2Ratio when converting to a code as 0.
tau2
The upper bound for log2Ratio when converting to a code as 0. Log2ratio between tau1 and tau2 is converted to 0 and 1 otherwise.
Author
Pan Tong (nickytong@gmail.com), Kevin R Coombes (krc@silicovore.com)
References
Tong P, Coombes KR. integIRTy: a method to identify altered
genes in cancer accounting for multiple mechanisms of regulation
using item response theory. Bioinformatics, 2012 Nov 15;
28(22):2861--9.