A binary matrix of the same dimension of input methy.
Arguments
methy
The methylation matrix for tumor samples. Each element represents the beta value which is
bounded between 0 and 1. Rows are genes and columns are samples.
methyCtr
Methylation matrix of normal controls. Genes should exactly the same as the tumor sample. The sample size are not
necessarily the same as tumor sample.
refUseMean
Logical indicating whether to use mean of normal sample as reference. Default is set to FALSE which means to use median
as it is more robust.
Author
Pan Tong (nickytong@gmail.com), Kevin R Coombes (krc@silicovore.com)
References
Tong P, Coombes KR. integIRTy: a method to identify altered
genes in cancer accounting for multiple mechanisms of regulation
using item response theory. Bioinformatics, 2012 Nov 15;
28(22):2861--9.